richardview.majumdar\_lab\_widgets.valco\_2\_way\_valve\_widget module
======================================================================

.. automodule:: richardview.majumdar_lab_widgets.valco_2_way_valve_widget
   :members:
   :undoc-members:
   :show-inheritance:
